summaryrefslogtreecommitdiffstats
path: root/examples/group.cpp
diff options
context:
space:
mode:
authorDimitri van Heesch <dimitri@stack.nl>2000-05-08 20:42:05 (GMT)
committerDimitri van Heesch <dimitri@stack.nl>2000-05-08 20:42:05 (GMT)
commit367c98ad291fd02781ae1c20a6e09e0b07dbec88 (patch)
tree28a24e8c88d32a50bc5bef6d49306553267dc5ab /examples/group.cpp
parent59bbbf5099f9bcf96d3585e4fc0669e091d3b9e7 (diff)
downloadDoxygen-367c98ad291fd02781ae1c20a6e09e0b07dbec88.zip
Doxygen-367c98ad291fd02781ae1c20a6e09e0b07dbec88.tar.gz
Doxygen-367c98ad291fd02781ae1c20a6e09e0b07dbec88.tar.bz2
Release-1.1.3
Diffstat (limited to 'examples/group.cpp')
-rw-r--r--examples/group.cpp13
1 files changed, 9 insertions, 4 deletions
diff --git a/examples/group.cpp b/examples/group.cpp
index 7bd3255..53ea371 100644
--- a/examples/group.cpp
+++ b/examples/group.cpp
@@ -10,6 +10,11 @@
* This is the third group
*/
+/*! \defgroup group4 The Fourth Group
+ * \ingroup group3
+ * Group 4 is a subgroup of group 3
+ */
+
/*! \ingroup group1
* \brief class C1 in group 1
*/
@@ -35,11 +40,11 @@ class C4 {};
*/
class C5 {};
/*! \ingroup group1 group2 group3
* \brief class C6 in all groups
* \sa \link group1 The first group\endlink, group2, group3
*/
-class C6 {};
+namespace N1 {};
/*! \file
* \ingroup group3
@@ -35,11 +40,11 @@ class C4 {};
*/
class C5 {};
-/*! \ingroup group1 group2 group3
- * \brief class C6 in all groups
- * \sa \link group1 The first group\endlink, group2, group3
+/*! \ingroup group1 group2 group3 group4
+ * namespace N1 is in all groups
+ * \sa \link group1 The first group\endlink, group2, group3, group4
*/